/****************************************************************************
** Meta object code from reading C++ file 'QtCore.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../QtCore/QtCore.qpb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QtCore.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QUrl::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QUrl",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QUrl, qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QUrl::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore4QUrlE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QUrl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QUrl *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUrl(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QChar::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QChar",
        "utf16CodePoint",
        "QtProtobuf::uint32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'utf16CodePoint'
        QtMocHelpers::PropertyData<QtProtobuf::uint32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QChar, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QCharE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QChar::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QCharE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QCharE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QChar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QChar *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::uint32*>(_v) = _t->utf16CodePoint(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUtf16CodePoint(*reinterpret_cast<QtProtobuf::uint32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QUuid::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QUuid",
        "rfc4122Uuid"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rfc4122Uuid'
        QtMocHelpers::PropertyData<QByteArray>(1, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QUuid, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QUuid::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QUuidE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QUuid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QUuid *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->rfc4122Uuid(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRfc4122Uuid(*reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QTimeZone::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QTimeZone",
        "offsetSeconds",
        "QtProtobuf::int32",
        "hasOffsetSeconds",
        "ianaId",
        "hasIanaId",
        "timeSpec",
        "TimeSpec",
        "hasTimeSpec"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'offsetSeconds'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'hasOffsetSeconds'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ianaId'
        QtMocHelpers::PropertyData<QByteArray>(4, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasIanaId'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'timeSpec'
        QtMocHelpers::PropertyData<TimeSpec>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'hasTimeSpec'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTimeZone, qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore9QTimeZoneE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QTimeZone::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore9QTimeZoneE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QTimeZoneE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QTimeZone::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QTimeZone *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->offsetSeconds_p(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasOffsetSeconds(); break;
        case 2: *reinterpret_cast<QByteArray*>(_v) = _t->ianaId_p(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasIanaId(); break;
        case 4: *reinterpret_cast<TimeSpec*>(_v) = _t->timeSpec_p(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasTimeSpec(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOffsetSeconds_p(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 2: _t->setIanaId_p(*reinterpret_cast<QByteArray*>(_v)); break;
        case 4: _t->setTimeSpec_p(*reinterpret_cast<TimeSpec*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QTime::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QTime",
        "millisecondsSinceMidnight",
        "QtProtobuf::int32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'millisecondsSinceMidnight'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTime, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QTimeE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QTime::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QTimeE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QTimeE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QTime *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->millisecondsSinceMidnight(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMillisecondsSinceMidnight(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QDate::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QDate",
        "julianDay",
        "QtProtobuf::int64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'julianDay'
        QtMocHelpers::PropertyData<QtProtobuf::int64>(1, 0x80000000 | 2, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QDate, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QDateE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QDate::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QDateE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QDateE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QDate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QDate *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int64 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int64*>(_v) = _t->julianDay(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setJulianDay(*reinterpret_cast<QtProtobuf::int64*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QDateTime::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QDateTime",
        "utcMsecsSinceUnixEpoch",
        "QtProtobuf::int64",
        "timeZone_p",
        "QtProtobufPrivate::QtCore::QTimeZone*",
        "hasTimeZone"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'utcMsecsSinceUnixEpoch'
        QtMocHelpers::PropertyData<QtProtobuf::int64>(1, 0x80000000 | 2, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'timeZone_p'
        QtMocHelpers::PropertyData<QtProtobufPrivate::QtCore::QTimeZone*>(3, 0x80000000 | 4, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasTimeZone'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QDateTime, qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore9QDateTimeE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QDateTime::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore9QDateTimeE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore9QDateTimeE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QDateTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QDateTime *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int64 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int64*>(_v) = _t->utcMsecsSinceUnixEpoch(); break;
        case 1: *reinterpret_cast<QtProtobufPrivate::QtCore::QTimeZone**>(_v) = _t->timeZone_p(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasTimeZone(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUtcMsecsSinceUnixEpoch(*reinterpret_cast<QtProtobuf::int64*>(_v)); break;
        case 1: _t->setTimeZone_p(*reinterpret_cast<QtProtobufPrivate::QtCore::QTimeZone**>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QSize::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QSize",
        "width",
        "QtProtobuf::int32",
        "height"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'width'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'height'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QSize, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QSizeE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QSize::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QSizeE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QSizeE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QSize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QSize *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->height(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidth(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 1: _t->setHeight(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QSizeF::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QSizeF",
        "width",
        "height"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'width'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'height'
        QtMocHelpers::PropertyData<double>(2, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QSizeF, qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QSizeF::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QSizeFE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QSizeF::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QSizeF *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->height(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidth(*reinterpret_cast<double*>(_v)); break;
        case 1: _t->setHeight(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QPoint::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QPoint",
        "x",
        "QtProtobuf::sint32",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<QtProtobuf::sint32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'y'
        QtMocHelpers::PropertyData<QtProtobuf::sint32>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QPoint, qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore6QPointE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QPoint::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore6QPointE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QPointE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QPoint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QPoint *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::sint32*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<QtProtobuf::sint32*>(_v) = _t->y(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<QtProtobuf::sint32*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<QtProtobuf::sint32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QPointF::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QPointF",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'y'
        QtMocHelpers::PropertyData<double>(2, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QPointF, qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QPointF::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore7QPointFE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QPointF::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QPointF *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->y(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<double*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QRect::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QRect",
        "x",
        "QtProtobuf::sint32",
        "y",
        "width",
        "QtProtobuf::int32",
        "height"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<QtProtobuf::sint32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'y'
        QtMocHelpers::PropertyData<QtProtobuf::sint32>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'width'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'height'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QRect, qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QRectE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QRect::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore5QRectE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore5QRectE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QRect::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QRect *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::sint32*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<QtProtobuf::sint32*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->height(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<QtProtobuf::sint32*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<QtProtobuf::sint32*>(_v)); break;
        case 2: _t->setWidth(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QRectF::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QRectF",
        "x",
        "y",
        "width",
        "height"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'y'
        QtMocHelpers::PropertyData<double>(2, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'width'
        QtMocHelpers::PropertyData<double>(3, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'height'
        QtMocHelpers::PropertyData<double>(4, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QRectF, qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QRectF::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore6QRectFE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QRectF::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QRectF *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<double*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->height(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<double*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<double*>(_v)); break;
        case 2: _t->setWidth(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QVersionNumber::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QVersionNumber",
        "segments",
        "QtProtobuf::int32List"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'segments'
        QtMocHelpers::PropertyData<QtProtobuf::int32List>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVersionNumber, qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate6QtCore14QVersionNumberE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QVersionNumber::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate6QtCore14QVersionNumberE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate6QtCore14QVersionNumberE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtCore::QVersionNumber::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QVersionNumber *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int32List*>(_v) = _t->segments(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSegments(*reinterpret_cast<QtProtobuf::int32List*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QUrl_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QUrl_QtProtobufNested",
        "QtProtobufFieldEnum",
        "UrlProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::UrlProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QUrl_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QUrl_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore21QUrl_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QChar_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QChar_QtProtobufNested",
        "QtProtobufFieldEnum",
        "Utf16CodePointProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::Utf16CodePointProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QChar_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QChar_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QChar_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QUuid_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QUuid_QtProtobufNested",
        "QtProtobufFieldEnum",
        "Rfc4122UuidProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::Rfc4122UuidProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QUuid_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QUuid_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QUuid_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QTimeZone_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QTimeZone_QtProtobufNested",
        "QtProtobufFieldEnum",
        "OffsetSecondsProtoFieldNumber",
        "IanaIdProtoFieldNumber",
        "TimeSpecProtoFieldNumber",
        "TimeSpec",
        "LocalTime",
        "UTC",
        "TimeZoneFields",
        "UninitializedField",
        "OffsetSeconds",
        "IanaId"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::OffsetSecondsProtoFieldNumber },
            {    3, QtProtobufFieldEnum::IanaIdProtoFieldNumber },
            {    4, QtProtobufFieldEnum::TimeSpecProtoFieldNumber },
        }),
        // enum 'TimeSpec'
        QtMocHelpers::EnumData<TimeSpec>(5, 5, QMC::EnumIsScoped).add({
            {    6, TimeSpec::LocalTime },
            {    7, TimeSpec::UTC },
        }),
        // enum 'TimeZoneFields'
        QtMocHelpers::EnumData<TimeZoneFields>(8, 8, QMC::EnumIsScoped).add({
            {    9, TimeZoneFields::UninitializedField },
            {   10, TimeZoneFields::OffsetSeconds },
            {   11, TimeZoneFields::IanaId },
            {    5, TimeZoneFields::TimeSpec },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QTimeZone_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QTimeZone_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore26QTimeZone_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QTime_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QTime_QtProtobufNested",
        "QtProtobufFieldEnum",
        "MillisecondsSinceMidnightProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::MillisecondsSinceMidnightProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QTime_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QTime_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QTime_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QDate_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QDate_QtProtobufNested",
        "QtProtobufFieldEnum",
        "JulianDayProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::JulianDayProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QDate_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QDate_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QDate_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QDateTime_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QDateTime_QtProtobufNested",
        "QtProtobufFieldEnum",
        "UtcMsecsSinceUnixEpochProtoFieldNumber",
        "TimeZoneProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::UtcMsecsSinceUnixEpochProtoFieldNumber },
            {    3, QtProtobufFieldEnum::TimeZoneProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QDateTime_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QDateTime_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore26QDateTime_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QSize_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QSize_QtProtobufNested",
        "QtProtobufFieldEnum",
        "WidthProtoFieldNumber",
        "HeightProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::WidthProtoFieldNumber },
            {    3, QtProtobufFieldEnum::HeightProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QSize_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QSize_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QSize_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QSizeF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QSizeF_QtProtobufNested",
        "QtProtobufFieldEnum",
        "WidthProtoFieldNumber",
        "HeightProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::WidthProtoFieldNumber },
            {    3, QtProtobufFieldEnum::HeightProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QSizeF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QSizeF_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QSizeF_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QPoint_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QPoint_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XProtoFieldNumber",
        "YProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QPoint_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QPoint_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QPoint_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QPointF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QPointF_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XProtoFieldNumber",
        "YProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QPointF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QPointF_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore24QPointF_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QRect_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QRect_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XProtoFieldNumber",
        "YProtoFieldNumber",
        "WidthProtoFieldNumber",
        "HeightProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YProtoFieldNumber },
            {    4, QtProtobufFieldEnum::WidthProtoFieldNumber },
            {    5, QtProtobufFieldEnum::HeightProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QRect_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QRect_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore22QRect_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QRectF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QRectF_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XProtoFieldNumber",
        "YProtoFieldNumber",
        "WidthProtoFieldNumber",
        "HeightProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YProtoFieldNumber },
            {    4, QtProtobufFieldEnum::WidthProtoFieldNumber },
            {    5, QtProtobufFieldEnum::HeightProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QRectF_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QRectF_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore23QRectF_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtCore::QVersionNumber_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtCore::QVersionNumber_QtProtobufNested",
        "QtProtobufFieldEnum",
        "SegmentsProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::SegmentsProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE =
    QtProtobufPrivate::QtCore::QVersionNumber_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtCore::QVersionNumber_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate6QtCore31QVersionNumber_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
