/****************************************************************************
** Meta object code from reading C++ file 'struct.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/struct.qpb.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'struct.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf6StructE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Struct::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf6StructE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Struct",
        "fields",
        "google::protobuf::Struct::FieldsEntry"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fields'
        QtMocHelpers::PropertyData<google::protobuf::Struct::FieldsEntry>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Struct, qt_meta_tag_ZN6google8protobuf6StructE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::Struct::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6StructE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6StructE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf6StructE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Struct::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Struct *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<google::protobuf::Struct::FieldsEntry*>(_v) = _t->fields(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFields(*reinterpret_cast<google::protobuf::Struct::FieldsEntry*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf5ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Value::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf5ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Value",
        "nullValue",
        "google::protobuf::NullValueGadget::NullValue",
        "hasNullValue",
        "numberValue",
        "hasNumberValue",
        "stringValue",
        "hasStringValue",
        "boolValue",
        "hasBoolValue",
        "structValue_p",
        "google::protobuf::Struct*",
        "hasStructValue",
        "listValue_p",
        "google::protobuf::ListValue*",
        "hasListValue"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'nullValue'
        QtMocHelpers::PropertyData<google::protobuf::NullValueGadget::NullValue>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'hasNullValue'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'numberValue'
        QtMocHelpers::PropertyData<double>(4, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasNumberValue'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'stringValue'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasStringValue'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'boolValue'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasBoolValue'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'structValue_p'
        QtMocHelpers::PropertyData<google::protobuf::Struct*>(10, 0x80000000 | 11, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasStructValue'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'listValue_p'
        QtMocHelpers::PropertyData<google::protobuf::ListValue*>(13, 0x80000000 | 14, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasListValue'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Value, qt_meta_tag_ZN6google8protobuf5ValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf5ValueE[] = {
    QMetaObject::SuperData::link<google::protobuf::NullValueGadget::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Value::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5ValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf5ValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf5ValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Value *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<google::protobuf::NullValueGadget::NullValue*>(_v) = _t->nullValue_p(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasNullValue(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->numberValue_p(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasNumberValue(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->stringValue_p(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasStringValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->boolValue_p(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasBoolValue(); break;
        case 8: *reinterpret_cast<google::protobuf::Struct**>(_v) = _t->structValue_p(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hasStructValue(); break;
        case 10: *reinterpret_cast<google::protobuf::ListValue**>(_v) = _t->listValue_p(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->hasListValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setNullValue_p(*reinterpret_cast<google::protobuf::NullValueGadget::NullValue*>(_v)); break;
        case 2: _t->setNumberValue_p(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setStringValue_p(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setBoolValue_p(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setStructValue_p(*reinterpret_cast<google::protobuf::Struct**>(_v)); break;
        case 10: _t->setListValue_p(*reinterpret_cast<google::protobuf::ListValue**>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf9ListValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::ListValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf9ListValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::ListValue",
        "values",
        "QList<google::protobuf::Value>",
        "valuesData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'values'
        QtMocHelpers::PropertyData<QList<google::protobuf::Value>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'valuesData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Value>>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ListValue, qt_meta_tag_ZN6google8protobuf9ListValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::ListValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9ListValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9ListValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf9ListValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::ListValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ListValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<google::protobuf::Value>*>(_v) = _t->values(); break;
        case 1: *reinterpret_cast<QList<google::protobuf::Value>*>(_v) = _t->values(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValues(*reinterpret_cast<QList<google::protobuf::Value>*>(_v)); break;
        case 1: _t->setValues(*reinterpret_cast<QList<google::protobuf::Value>*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf15NullValueGadgetE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::NullValueGadget::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf15NullValueGadgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::NullValueGadget",
        "NullValue",
        "NULL_VALUE"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'NullValue'
        QtMocHelpers::EnumData<NullValue>(1, 1, QMC::EnumIsScoped).add({
            {    2, NullValue::NULL_VALUE },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf15NullValueGadgetE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf15NullValueGadgetE =
    google::protobuf::NullValueGadget::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf15NullValueGadgetE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf15NullValueGadgetE =
    qt_staticMetaObjectContent_ZN6google8protobuf15NullValueGadgetE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf15NullValueGadgetE =
    qt_staticMetaObjectContent_ZN6google8protobuf15NullValueGadgetE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::NullValueGadget::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf15NullValueGadgetE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf15NullValueGadgetE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf15NullValueGadgetE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf23Struct_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Struct_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Struct_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Struct_QtProtobufNested",
        "QtProtobufFieldEnum",
        "FieldsProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::FieldsProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf23Struct_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf23Struct_QtProtobufNestedE =
    google::protobuf::Struct_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Struct_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf23Struct_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Struct_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Struct_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Struct_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Struct_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Struct_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Struct_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Struct_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf22Value_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Value_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Value_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NullValueProtoFieldNumber",
        "NumberValueProtoFieldNumber",
        "StringValueProtoFieldNumber",
        "BoolValueProtoFieldNumber",
        "StructValueProtoFieldNumber",
        "ListValueProtoFieldNumber",
        "KindFields",
        "UninitializedField",
        "NullValue",
        "NumberValue",
        "StringValue",
        "BoolValue",
        "StructValue",
        "ListValue"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NullValueProtoFieldNumber },
            {    3, QtProtobufFieldEnum::NumberValueProtoFieldNumber },
            {    4, QtProtobufFieldEnum::StringValueProtoFieldNumber },
            {    5, QtProtobufFieldEnum::BoolValueProtoFieldNumber },
            {    6, QtProtobufFieldEnum::StructValueProtoFieldNumber },
            {    7, QtProtobufFieldEnum::ListValueProtoFieldNumber },
        }),
        // enum 'KindFields'
        QtMocHelpers::EnumData<KindFields>(8, 8, QMC::EnumIsScoped).add({
            {    9, KindFields::UninitializedField },
            {   10, KindFields::NullValue },
            {   11, KindFields::NumberValue },
            {   12, KindFields::StringValue },
            {   13, KindFields::BoolValue },
            {   14, KindFields::StructValue },
            {   15, KindFields::ListValue },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf22Value_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf22Value_QtProtobufNestedE =
    google::protobuf::Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Value_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf22Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Value_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Value_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Value_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Value_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Value_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Value_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf26ListValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::ListValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26ListValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::ListValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValuesProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValuesProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf26ListValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf26ListValue_QtProtobufNestedE =
    google::protobuf::ListValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26ListValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf26ListValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26ListValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26ListValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26ListValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::ListValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26ListValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26ListValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26ListValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
