
#include "QtCore/QtCore.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

QT_BEGIN_NAMESPACE
namespace QtProtobufPrivate::QtCore {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQUrl(qRegisterProtobufType<QUrl>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQChar(qRegisterProtobufType<QChar>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQUuid(qRegisterProtobufType<QUuid>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQTimeZone(qRegisterProtobufType<QTimeZone>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQTime(qRegisterProtobufType<QTime>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQDate(qRegisterProtobufType<QDate>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQDateTime(qRegisterProtobufType<QDateTime>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQSize(qRegisterProtobufType<QSize>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQSizeF(qRegisterProtobufType<QSizeF>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQPoint(qRegisterProtobufType<QPoint>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQPointF(qRegisterProtobufType<QPointF>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQRect(qRegisterProtobufType<QRect>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQRectF(qRegisterProtobufType<QRectF>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQVersionNumber(qRegisterProtobufType<QVersionNumber>);
static bool RegisterQtCoreProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace QtProtobufPrivate::QtCore
QT_END_NAMESPACE

