/****************************************************************************
** Meta object code from reading C++ file 'api.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/api.qpb.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'api.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf3ApiE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Api::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf3ApiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Api",
        "name",
        "methods",
        "QList<google::protobuf::Method>",
        "methodsData",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData",
        "version",
        "sourceContext_p",
        "google::protobuf::SourceContext*",
        "hasSourceContext",
        "mixins",
        "QList<google::protobuf::Mixin>",
        "mixinsData",
        "syntax",
        "google::protobuf::SyntaxGadget::Syntax",
        "edition"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'methods'
        QtMocHelpers::PropertyData<QList<google::protobuf::Method>>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'methodsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Method>>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'sourceContext_p'
        QtMocHelpers::PropertyData<google::protobuf::SourceContext*>(9, 0x80000000 | 10, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasSourceContext'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'mixins'
        QtMocHelpers::PropertyData<QList<google::protobuf::Mixin>>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mixinsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Mixin>>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'syntax'
        QtMocHelpers::PropertyData<google::protobuf::SyntaxGadget::Syntax>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'edition'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Api, qt_meta_tag_ZN6google8protobuf3ApiE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf3ApiE[] = {
    QMetaObject::SuperData::link<google::protobuf::SyntaxGadget::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Api::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf3ApiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf3ApiE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf3ApiE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf3ApiE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Api::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Api *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QList<google::protobuf::Method>*>(_v) = _t->methods(); break;
        case 2: *reinterpret_cast<QList<google::protobuf::Method>*>(_v) = _t->methods(); break;
        case 3: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 4: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 6: *reinterpret_cast<google::protobuf::SourceContext**>(_v) = _t->sourceContext_p(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasSourceContext(); break;
        case 8: *reinterpret_cast<QList<google::protobuf::Mixin>*>(_v) = _t->mixins(); break;
        case 9: *reinterpret_cast<QList<google::protobuf::Mixin>*>(_v) = _t->mixins(); break;
        case 10: *reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v) = _t->syntax(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->edition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setMethods(*reinterpret_cast<QList<google::protobuf::Method>*>(_v)); break;
        case 2: _t->setMethods(*reinterpret_cast<QList<google::protobuf::Method>*>(_v)); break;
        case 3: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 4: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 5: _t->setVersion(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSourceContext_p(*reinterpret_cast<google::protobuf::SourceContext**>(_v)); break;
        case 8: _t->setMixins(*reinterpret_cast<QList<google::protobuf::Mixin>*>(_v)); break;
        case 9: _t->setMixins(*reinterpret_cast<QList<google::protobuf::Mixin>*>(_v)); break;
        case 10: _t->setSyntax(*reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v)); break;
        case 11: _t->setEdition(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf6MethodE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Method::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf6MethodE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Method",
        "name",
        "requestTypeUrl",
        "requestStreaming",
        "responseTypeUrl",
        "responseStreaming",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData",
        "syntax",
        "google::protobuf::SyntaxGadget::Syntax",
        "edition"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'requestTypeUrl'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'requestStreaming'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'responseTypeUrl'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'responseStreaming'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'syntax'
        QtMocHelpers::PropertyData<google::protobuf::SyntaxGadget::Syntax>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'edition'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Method, qt_meta_tag_ZN6google8protobuf6MethodE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf6MethodE[] = {
    QMetaObject::SuperData::link<google::protobuf::SyntaxGadget::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Method::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6MethodE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6MethodE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf6MethodE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf6MethodE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Method::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Method *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->requestTypeUrl(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->requestStreaming(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->responseTypeUrl(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->responseStreaming(); break;
        case 5: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 6: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 7: *reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v) = _t->syntax(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->edition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setRequestTypeUrl(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setRequestStreaming(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setResponseTypeUrl(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setResponseStreaming(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 6: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 7: _t->setSyntax(*reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v)); break;
        case 8: _t->setEdition(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf5MixinE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Mixin::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf5MixinE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Mixin",
        "name",
        "root"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'root'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Mixin, qt_meta_tag_ZN6google8protobuf5MixinE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::Mixin::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5MixinE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5MixinE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf5MixinE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Mixin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Mixin *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->root(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setRoot(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf20Api_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Api_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf20Api_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Api_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "MethodsProtoFieldNumber",
        "OptionsProtoFieldNumber",
        "VersionProtoFieldNumber",
        "SourceContextProtoFieldNumber",
        "MixinsProtoFieldNumber",
        "SyntaxProtoFieldNumber",
        "EditionProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::MethodsProtoFieldNumber },
            {    4, QtProtobufFieldEnum::OptionsProtoFieldNumber },
            {    5, QtProtobufFieldEnum::VersionProtoFieldNumber },
            {    6, QtProtobufFieldEnum::SourceContextProtoFieldNumber },
            {    7, QtProtobufFieldEnum::MixinsProtoFieldNumber },
            {    8, QtProtobufFieldEnum::SyntaxProtoFieldNumber },
            {    9, QtProtobufFieldEnum::EditionProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf20Api_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf20Api_QtProtobufNestedE =
    google::protobuf::Api_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf20Api_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf20Api_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf20Api_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf20Api_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf20Api_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Api_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf20Api_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf20Api_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf20Api_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf23Method_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Method_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Method_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Method_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "RequestTypeUrlProtoFieldNumber",
        "RequestStreamingProtoFieldNumber",
        "ResponseTypeUrlProtoFieldNumber",
        "ResponseStreamingProtoFieldNumber",
        "OptionsProtoFieldNumber",
        "SyntaxProtoFieldNumber",
        "EditionProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::RequestTypeUrlProtoFieldNumber },
            {    4, QtProtobufFieldEnum::RequestStreamingProtoFieldNumber },
            {    5, QtProtobufFieldEnum::ResponseTypeUrlProtoFieldNumber },
            {    6, QtProtobufFieldEnum::ResponseStreamingProtoFieldNumber },
            {    7, QtProtobufFieldEnum::OptionsProtoFieldNumber },
            {    8, QtProtobufFieldEnum::SyntaxProtoFieldNumber },
            {    9, QtProtobufFieldEnum::EditionProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf23Method_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf23Method_QtProtobufNestedE =
    google::protobuf::Method_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Method_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf23Method_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Method_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Method_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Method_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Method_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Method_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Method_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Method_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf22Mixin_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Mixin_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Mixin_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Mixin_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "RootProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::RootProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf22Mixin_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf22Mixin_QtProtobufNestedE =
    google::protobuf::Mixin_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Mixin_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf22Mixin_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Mixin_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Mixin_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Mixin_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Mixin_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Mixin_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Mixin_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Mixin_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
