/****************************************************************************
** Meta object code from reading C++ file 'duration.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/duration.qpb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'duration.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf8DurationE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Duration::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf8DurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Duration",
        "seconds",
        "QtProtobuf::int64",
        "nanos",
        "QtProtobuf::int32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'seconds'
        QtMocHelpers::PropertyData<QtProtobuf::int64>(1, 0x80000000 | 2, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'nanos'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Duration, qt_meta_tag_ZN6google8protobuf8DurationE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf8DurationE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Duration::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf8DurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf8DurationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf8DurationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf8DurationE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Duration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Duration *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int64 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int64*>(_v) = _t->seconds(); break;
        case 1: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->nanos(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSeconds(*reinterpret_cast<QtProtobuf::int64*>(_v)); break;
        case 1: _t->setNanos(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf25Duration_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Duration_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf25Duration_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Duration_QtProtobufNested",
        "QtProtobufFieldEnum",
        "SecondsProtoFieldNumber",
        "NanosProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::SecondsProtoFieldNumber },
            {    3, QtProtobufFieldEnum::NanosProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf25Duration_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf25Duration_QtProtobufNestedE =
    google::protobuf::Duration_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf25Duration_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf25Duration_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf25Duration_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf25Duration_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf25Duration_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Duration_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf25Duration_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf25Duration_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf25Duration_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
