
#include "google/protobuf/timestamp.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarTimestamp(qRegisterProtobufType<Timestamp>);
static bool RegisterTimestampProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

