
#include "google/protobuf/struct.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarStruct(qRegisterProtobufType<Struct>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarValue(qRegisterProtobufType<Value>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarListValue(qRegisterProtobufType<ListValue>);
static bool RegisterStructProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

