
#include "QtGui/QtGui.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

QT_BEGIN_NAMESPACE
namespace QtProtobufPrivate::QtGui {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQRgba64(qRegisterProtobufType<QRgba64>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQColor(qRegisterProtobufType<QColor>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQMatrix4x4(qRegisterProtobufType<QMatrix4x4>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQVector2D(qRegisterProtobufType<QVector2D>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQVector3D(qRegisterProtobufType<QVector3D>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQVector4D(qRegisterProtobufType<QVector4D>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQTransform(qRegisterProtobufType<QTransform>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQQuaternion(qRegisterProtobufType<QQuaternion>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarQImage(qRegisterProtobufType<QImage>);
static bool RegisterQtGuiProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace QtProtobufPrivate::QtGui
QT_END_NAMESPACE

