
#include "google/protobuf/source_context.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarSourceContext(qRegisterProtobufType<SourceContext>);
static bool RegisterSource_contextProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

