/****************************************************************************
** Meta object code from reading C++ file 'any.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/any.qpb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'any.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf3AnyE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Any::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf3AnyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Any",
        "typeUrl",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'typeUrl'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'value'
        QtMocHelpers::PropertyData<QByteArray>(2, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Any, qt_meta_tag_ZN6google8protobuf3AnyE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::Any::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf3AnyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf3AnyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf3AnyE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Any::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Any *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->typeUrl(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTypeUrl(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setValue(*reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf20Any_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Any_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf20Any_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Any_QtProtobufNested",
        "QtProtobufFieldEnum",
        "TypeUrlProtoFieldNumber",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::TypeUrlProtoFieldNumber },
            {    3, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf20Any_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf20Any_QtProtobufNestedE =
    google::protobuf::Any_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf20Any_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf20Any_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf20Any_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf20Any_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf20Any_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Any_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf20Any_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf20Any_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf20Any_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
