
#include "google/protobuf/wrappers.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarDoubleValue(qRegisterProtobufType<DoubleValue>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarFloatValue(qRegisterProtobufType<FloatValue>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarInt64Value(qRegisterProtobufType<Int64Value>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarUInt64Value(qRegisterProtobufType<UInt64Value>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarInt32Value(qRegisterProtobufType<Int32Value>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarUInt32Value(qRegisterProtobufType<UInt32Value>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarBoolValue(qRegisterProtobufType<BoolValue>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarStringValue(qRegisterProtobufType<StringValue>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarBytesValue(qRegisterProtobufType<BytesValue>);
static bool RegisterWrappersProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

