
#include "google/protobuf/field_mask.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarFieldMask(qRegisterProtobufType<FieldMask>);
static bool RegisterField_maskProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

