
#include "google/protobuf/empty.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarEmpty(qRegisterProtobufType<Empty>);
static bool RegisterEmptyProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

