
#include "google/protobuf/type.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarType(qRegisterProtobufType<Type>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarField(qRegisterProtobufType<Field>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarEnum(qRegisterProtobufType<Enum>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarEnumValue(qRegisterProtobufType<EnumValue>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarOption(qRegisterProtobufType<Option>);
static bool RegisterTypeProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

