
#include "google/protobuf/duration.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarDuration(qRegisterProtobufType<Duration>);
static bool RegisterDurationProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

