/****************************************************************************
** Meta object code from reading C++ file 'type.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/type.qpb.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'type.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf4TypeE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Type::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf4TypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Type",
        "name",
        "fields",
        "QList<google::protobuf::Field>",
        "fieldsData",
        "oneofs",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData",
        "sourceContext_p",
        "google::protobuf::SourceContext*",
        "hasSourceContext",
        "syntax",
        "google::protobuf::SyntaxGadget::Syntax",
        "edition"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fields'
        QtMocHelpers::PropertyData<QList<google::protobuf::Field>>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'fieldsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Field>>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'oneofs'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'sourceContext_p'
        QtMocHelpers::PropertyData<google::protobuf::SourceContext*>(9, 0x80000000 | 10, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasSourceContext'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'syntax'
        QtMocHelpers::PropertyData<google::protobuf::SyntaxGadget::Syntax>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'edition'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Type, qt_meta_tag_ZN6google8protobuf4TypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf4TypeE[] = {
    QMetaObject::SuperData::link<google::protobuf::SyntaxGadget::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Type::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf4TypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf4TypeE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf4TypeE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf4TypeE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Type::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Type *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QList<google::protobuf::Field>*>(_v) = _t->fields(); break;
        case 2: *reinterpret_cast<QList<google::protobuf::Field>*>(_v) = _t->fields(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->oneofs(); break;
        case 4: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 5: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 6: *reinterpret_cast<google::protobuf::SourceContext**>(_v) = _t->sourceContext_p(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasSourceContext(); break;
        case 8: *reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v) = _t->syntax(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->edition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFields(*reinterpret_cast<QList<google::protobuf::Field>*>(_v)); break;
        case 2: _t->setFields(*reinterpret_cast<QList<google::protobuf::Field>*>(_v)); break;
        case 3: _t->setOneofs(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 5: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 6: _t->setSourceContext_p(*reinterpret_cast<google::protobuf::SourceContext**>(_v)); break;
        case 8: _t->setSyntax(*reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v)); break;
        case 9: _t->setEdition(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf5FieldE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Field::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf5FieldE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Field",
        "kind",
        "Kind",
        "cardinality",
        "Cardinality",
        "number",
        "QtProtobuf::int32",
        "name",
        "typeUrl",
        "oneofIndex",
        "packed",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData",
        "jsonName",
        "defaultValue"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'kind'
        QtMocHelpers::PropertyData<Kind>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'cardinality'
        QtMocHelpers::PropertyData<Cardinality>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'number'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'typeUrl'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'oneofIndex'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(9, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'packed'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'jsonName'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'defaultValue'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Field, qt_meta_tag_ZN6google8protobuf5FieldE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf5FieldE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Field::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5FieldE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf5FieldE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf5FieldE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf5FieldE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Field::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Field *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Kind*>(_v) = _t->kind(); break;
        case 1: *reinterpret_cast<Cardinality*>(_v) = _t->cardinality(); break;
        case 2: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->number(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->typeUrl(); break;
        case 5: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->oneofIndex(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->packed(); break;
        case 7: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 8: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->jsonName(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->defaultValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKind(*reinterpret_cast<Kind*>(_v)); break;
        case 1: _t->setCardinality(*reinterpret_cast<Cardinality*>(_v)); break;
        case 2: _t->setNumber(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setTypeUrl(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setOneofIndex(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 6: _t->setPacked(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 8: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 9: _t->setJsonName(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setDefaultValue(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf4EnumE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Enum::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf4EnumE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Enum",
        "name",
        "enumvalue",
        "QList<google::protobuf::EnumValue>",
        "enumvalueData",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData",
        "sourceContext_p",
        "google::protobuf::SourceContext*",
        "hasSourceContext",
        "syntax",
        "google::protobuf::SyntaxGadget::Syntax",
        "edition"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enumvalue'
        QtMocHelpers::PropertyData<QList<google::protobuf::EnumValue>>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'enumvalueData'
        QtMocHelpers::PropertyData<QList<google::protobuf::EnumValue>>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(7, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'sourceContext_p'
        QtMocHelpers::PropertyData<google::protobuf::SourceContext*>(8, 0x80000000 | 9, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasSourceContext'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'syntax'
        QtMocHelpers::PropertyData<google::protobuf::SyntaxGadget::Syntax>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'edition'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Enum, qt_meta_tag_ZN6google8protobuf4EnumE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf4EnumE[] = {
    QMetaObject::SuperData::link<google::protobuf::SyntaxGadget::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Enum::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf4EnumE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf4EnumE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf4EnumE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf4EnumE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Enum::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Enum *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QList<google::protobuf::EnumValue>*>(_v) = _t->enumvalue(); break;
        case 2: *reinterpret_cast<QList<google::protobuf::EnumValue>*>(_v) = _t->enumvalue(); break;
        case 3: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 4: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 5: *reinterpret_cast<google::protobuf::SourceContext**>(_v) = _t->sourceContext_p(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasSourceContext(); break;
        case 7: *reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v) = _t->syntax(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->edition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setEnumvalue(*reinterpret_cast<QList<google::protobuf::EnumValue>*>(_v)); break;
        case 2: _t->setEnumvalue(*reinterpret_cast<QList<google::protobuf::EnumValue>*>(_v)); break;
        case 3: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 4: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 5: _t->setSourceContext_p(*reinterpret_cast<google::protobuf::SourceContext**>(_v)); break;
        case 7: _t->setSyntax(*reinterpret_cast<google::protobuf::SyntaxGadget::Syntax*>(_v)); break;
        case 8: _t->setEdition(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf9EnumValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::EnumValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf9EnumValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::EnumValue",
        "name",
        "number",
        "QtProtobuf::int32",
        "options",
        "QList<google::protobuf::Option>",
        "optionsData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'number'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'options'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'optionsData'
        QtMocHelpers::PropertyData<QList<google::protobuf::Option>>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EnumValue, qt_meta_tag_ZN6google8protobuf9EnumValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf9EnumValueE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::EnumValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9EnumValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9EnumValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf9EnumValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf9EnumValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::EnumValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<EnumValue *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->number(); break;
        case 2: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        case 3: *reinterpret_cast<QList<google::protobuf::Option>*>(_v) = _t->options(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setNumber(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        case 2: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        case 3: _t->setOptions(*reinterpret_cast<QList<google::protobuf::Option>*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf6OptionE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Option::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf6OptionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Option",
        "name",
        "value",
        "QtProtobuf::Any"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'value'
        QtMocHelpers::PropertyData<QtProtobuf::Any>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Option, qt_meta_tag_ZN6google8protobuf6OptionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf6OptionE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Option::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6OptionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf6OptionE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf6OptionE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf6OptionE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Option::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Option *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QtProtobuf::Any*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setValue(*reinterpret_cast<QtProtobuf::Any*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf12SyntaxGadgetE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::SyntaxGadget::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf12SyntaxGadgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::SyntaxGadget",
        "Syntax",
        "SYNTAX_PROTO2",
        "SYNTAX_PROTO3",
        "SYNTAX_EDITIONS"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Syntax'
        QtMocHelpers::EnumData<Syntax>(1, 1, QMC::EnumIsScoped).add({
            {    2, Syntax::SYNTAX_PROTO2 },
            {    3, Syntax::SYNTAX_PROTO3 },
            {    4, Syntax::SYNTAX_EDITIONS },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf12SyntaxGadgetE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf12SyntaxGadgetE =
    google::protobuf::SyntaxGadget::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf12SyntaxGadgetE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf12SyntaxGadgetE =
    qt_staticMetaObjectContent_ZN6google8protobuf12SyntaxGadgetE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf12SyntaxGadgetE =
    qt_staticMetaObjectContent_ZN6google8protobuf12SyntaxGadgetE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::SyntaxGadget::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf12SyntaxGadgetE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf12SyntaxGadgetE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf12SyntaxGadgetE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf21Type_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Type_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf21Type_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Type_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "FieldsProtoFieldNumber",
        "OneofsProtoFieldNumber",
        "OptionsProtoFieldNumber",
        "SourceContextProtoFieldNumber",
        "SyntaxProtoFieldNumber",
        "EditionProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::FieldsProtoFieldNumber },
            {    4, QtProtobufFieldEnum::OneofsProtoFieldNumber },
            {    5, QtProtobufFieldEnum::OptionsProtoFieldNumber },
            {    6, QtProtobufFieldEnum::SourceContextProtoFieldNumber },
            {    7, QtProtobufFieldEnum::SyntaxProtoFieldNumber },
            {    8, QtProtobufFieldEnum::EditionProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf21Type_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf21Type_QtProtobufNestedE =
    google::protobuf::Type_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf21Type_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf21Type_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf21Type_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf21Type_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf21Type_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Type_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf21Type_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf21Type_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf21Type_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf22Field_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Field_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Field_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Field_QtProtobufNested",
        "QtProtobufFieldEnum",
        "KindProtoFieldNumber",
        "CardinalityProtoFieldNumber",
        "NumberProtoFieldNumber",
        "NameProtoFieldNumber",
        "TypeUrlProtoFieldNumber",
        "OneofIndexProtoFieldNumber",
        "PackedProtoFieldNumber",
        "OptionsProtoFieldNumber",
        "JsonNameProtoFieldNumber",
        "DefaultValueProtoFieldNumber",
        "Kind",
        "TYPE_UNKNOWN",
        "TYPE_DOUBLE",
        "TYPE_FLOAT",
        "TYPE_INT64",
        "TYPE_UINT64",
        "TYPE_INT32",
        "TYPE_FIXED64",
        "TYPE_FIXED32",
        "TYPE_BOOL",
        "TYPE_STRING",
        "TYPE_GROUP",
        "TYPE_MESSAGE",
        "TYPE_BYTES",
        "TYPE_UINT32",
        "TYPE_ENUM",
        "TYPE_SFIXED32",
        "TYPE_SFIXED64",
        "TYPE_SINT32",
        "TYPE_SINT64",
        "Cardinality",
        "CARDINALITY_UNKNOWN",
        "CARDINALITY_OPTIONAL",
        "CARDINALITY_REQUIRED",
        "CARDINALITY_REPEATED"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::KindProtoFieldNumber },
            {    3, QtProtobufFieldEnum::CardinalityProtoFieldNumber },
            {    4, QtProtobufFieldEnum::NumberProtoFieldNumber },
            {    5, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    6, QtProtobufFieldEnum::TypeUrlProtoFieldNumber },
            {    7, QtProtobufFieldEnum::OneofIndexProtoFieldNumber },
            {    8, QtProtobufFieldEnum::PackedProtoFieldNumber },
            {    9, QtProtobufFieldEnum::OptionsProtoFieldNumber },
            {   10, QtProtobufFieldEnum::JsonNameProtoFieldNumber },
            {   11, QtProtobufFieldEnum::DefaultValueProtoFieldNumber },
        }),
        // enum 'Kind'
        QtMocHelpers::EnumData<Kind>(12, 12, QMC::EnumIsScoped).add({
            {   13, Kind::TYPE_UNKNOWN },
            {   14, Kind::TYPE_DOUBLE },
            {   15, Kind::TYPE_FLOAT },
            {   16, Kind::TYPE_INT64 },
            {   17, Kind::TYPE_UINT64 },
            {   18, Kind::TYPE_INT32 },
            {   19, Kind::TYPE_FIXED64 },
            {   20, Kind::TYPE_FIXED32 },
            {   21, Kind::TYPE_BOOL },
            {   22, Kind::TYPE_STRING },
            {   23, Kind::TYPE_GROUP },
            {   24, Kind::TYPE_MESSAGE },
            {   25, Kind::TYPE_BYTES },
            {   26, Kind::TYPE_UINT32 },
            {   27, Kind::TYPE_ENUM },
            {   28, Kind::TYPE_SFIXED32 },
            {   29, Kind::TYPE_SFIXED64 },
            {   30, Kind::TYPE_SINT32 },
            {   31, Kind::TYPE_SINT64 },
        }),
        // enum 'Cardinality'
        QtMocHelpers::EnumData<Cardinality>(32, 32, QMC::EnumIsScoped).add({
            {   33, Cardinality::CARDINALITY_UNKNOWN },
            {   34, Cardinality::CARDINALITY_OPTIONAL },
            {   35, Cardinality::CARDINALITY_REQUIRED },
            {   36, Cardinality::CARDINALITY_REPEATED },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf22Field_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf22Field_QtProtobufNestedE =
    google::protobuf::Field_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf22Field_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf22Field_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Field_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Field_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf22Field_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Field_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Field_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf22Field_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf22Field_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf21Enum_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Enum_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf21Enum_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Enum_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "EnumvalueProtoFieldNumber",
        "OptionsProtoFieldNumber",
        "SourceContextProtoFieldNumber",
        "SyntaxProtoFieldNumber",
        "EditionProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::EnumvalueProtoFieldNumber },
            {    4, QtProtobufFieldEnum::OptionsProtoFieldNumber },
            {    5, QtProtobufFieldEnum::SourceContextProtoFieldNumber },
            {    6, QtProtobufFieldEnum::SyntaxProtoFieldNumber },
            {    7, QtProtobufFieldEnum::EditionProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf21Enum_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf21Enum_QtProtobufNestedE =
    google::protobuf::Enum_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf21Enum_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf21Enum_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf21Enum_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf21Enum_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf21Enum_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Enum_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf21Enum_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf21Enum_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf21Enum_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf26EnumValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::EnumValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26EnumValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::EnumValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "NumberProtoFieldNumber",
        "OptionsProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::NumberProtoFieldNumber },
            {    4, QtProtobufFieldEnum::OptionsProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf26EnumValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE =
    google::protobuf::EnumValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26EnumValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::EnumValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26EnumValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf23Option_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Option_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Option_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Option_QtProtobufNested",
        "QtProtobufFieldEnum",
        "NameProtoFieldNumber",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::NameProtoFieldNumber },
            {    3, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf23Option_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf23Option_QtProtobufNestedE =
    google::protobuf::Option_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf23Option_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf23Option_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Option_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Option_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf23Option_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Option_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Option_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf23Option_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf23Option_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
