/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qqmlgrpcchanneloptions_p.h>)
#  include <private/qqmlgrpcchanneloptions_p.h>
#endif
#if __has_include(<private/qqmlgrpchttp2channel_p.h>)
#  include <private/qqmlgrpchttp2channel_p.h>
#endif
#if __has_include(<private/qqmlgrpcmetadata_p.h>)
#  include <private/qqmlgrpcmetadata_p.h>
#endif
#if __has_include(<private/qqmlgrpcnamespace_p.h>)
#  include <private/qqmlgrpcnamespace_p.h>
#endif
#if __has_include(<qqmlgrpccalloptions.h>)
#  include <qqmlgrpccalloptions.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtGrpc()
{
    qmlRegisterModule("QtGrpc", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QQmlAbstractGrpcChannel *>().id();
    qmlRegisterTypesAndRevisions<QQmlGrpcChannelOptions>("QtGrpc", 6);
    qmlRegisterTypesAndRevisions<QQmlGrpcHttp2Channel>("QtGrpc", 6);
    qmlRegisterTypesAndRevisions<QQmlGrpcMetadata>("QtGrpc", 6);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &QtGrpc::staticMetaObject;},
            "QtGrpc");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&QtGrpc::staticMetaObject, "QtGrpc", 6, nullptr, &QtGrpcForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<QtGrpc::SerializationFormat>("QtGrpc::SerializationFormat");
    qmlRegisterEnum<QtGrpc::StatusCode>("QtGrpc::StatusCode");
    qmlRegisterEnum<QtGrpc::RpcType>("QtGrpc::RpcType");
    qmlRegisterEnum<QtGrpc::CompressionAlgorithm>("QtGrpc::CompressionAlgorithm");
    qmlRegisterEnum<QtGrpc::CompressionAlgorithms>("QtGrpc::CompressionAlgorithms");
    qmlRegisterEnum<QtGrpc::CompressionAlgorithm>("QtGrpc::CompressionAlgorithm");
    qmlRegisterTypesAndRevisions<QtGrpcQuickPrivate::QQmlGrpcCallOptions>("QtGrpc", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtGrpc", 6, 12);
}

static const QQmlModuleRegistration qtGrpcRegistration("QtGrpc", qml_register_types_QtGrpc);
