/****************************************************************************
** Meta object code from reading C++ file 'qtgrpcnamespace.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtgrpc/src/grpc/qtgrpcnamespace.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtgrpcnamespace.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6QtGrpcE_t {};
} // unnamed namespace

template <> constexpr inline auto QtGrpc::qt_create_metaobjectdata<qt_meta_tag_ZN6QtGrpcE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtGrpc",
        "RegisterEnumClassesUnscoped",
        "false",
        "SerializationFormat",
        "Default",
        "Protobuf",
        "Json",
        "StatusCode",
        "Ok",
        "Cancelled",
        "Unknown",
        "InvalidArgument",
        "DeadlineExceeded",
        "NotFound",
        "AlreadyExists",
        "PermissionDenied",
        "ResourceExhausted",
        "FailedPrecondition",
        "Aborted",
        "OutOfRange",
        "Unimplemented",
        "Internal",
        "Unavailable",
        "DataLoss",
        "Unauthenticated",
        "RpcType",
        "UnaryCall",
        "ServerStreaming",
        "ClientStreaming",
        "BidiStreaming",
        "CompressionAlgorithm",
        "Identity",
        "Deflate",
        "Gzip",
        "CompressionAlgorithms"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SerializationFormat'
        QtMocHelpers::EnumData<SerializationFormat>(3, 3, QMC::EnumIsScoped).add({
            {    4, SerializationFormat::Default },
            {    5, SerializationFormat::Protobuf },
            {    6, SerializationFormat::Json },
        }),
        // enum 'StatusCode'
        QtMocHelpers::EnumData<StatusCode>(7, 7, QMC::EnumIsScoped).add({
            {    8, StatusCode::Ok },
            {    9, StatusCode::Cancelled },
            {   10, StatusCode::Unknown },
            {   11, StatusCode::InvalidArgument },
            {   12, StatusCode::DeadlineExceeded },
            {   13, StatusCode::NotFound },
            {   14, StatusCode::AlreadyExists },
            {   15, StatusCode::PermissionDenied },
            {   16, StatusCode::ResourceExhausted },
            {   17, StatusCode::FailedPrecondition },
            {   18, StatusCode::Aborted },
            {   19, StatusCode::OutOfRange },
            {   20, StatusCode::Unimplemented },
            {   21, StatusCode::Internal },
            {   22, StatusCode::Unavailable },
            {   23, StatusCode::DataLoss },
            {   24, StatusCode::Unauthenticated },
        }),
        // enum 'RpcType'
        QtMocHelpers::EnumData<RpcType>(25, 25, QMC::EnumIsScoped).add({
            {   26, RpcType::UnaryCall },
            {   27, RpcType::ServerStreaming },
            {   28, RpcType::ClientStreaming },
            {   29, RpcType::BidiStreaming },
        }),
        // enum 'CompressionAlgorithm'
        QtMocHelpers::EnumData<CompressionAlgorithm>(30, 30, QMC::EnumIsScoped).add({
            {   31, CompressionAlgorithm::Identity },
            {   32, CompressionAlgorithm::Deflate },
            {   33, CompressionAlgorithm::Gzip },
        }),
        // flag 'CompressionAlgorithms'
        QtMocHelpers::EnumData<CompressionAlgorithms>(34, 30, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   31, CompressionAlgorithm::Identity },
            {   32, CompressionAlgorithm::Deflate },
            {   33, CompressionAlgorithm::Gzip },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6QtGrpcE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN6QtGrpcE =
    QtGrpc::qt_create_metaobjectdata<qt_meta_tag_ZN6QtGrpcE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6QtGrpcE =
    qt_staticMetaObjectContent_ZN6QtGrpcE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6QtGrpcE =
    qt_staticMetaObjectContent_ZN6QtGrpcE.relocatingData;

Q_CONSTINIT const QMetaObject QtGrpc::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6QtGrpcE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6QtGrpcE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6QtGrpcE.metaTypes,
    nullptr
} };

QT_WARNING_POP
