
#include "google/protobuf/any.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarAny(qRegisterProtobufType<Any>);
static bool RegisterAnyProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

