/****************************************************************************
** Meta object code from reading C++ file 'QtGui.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../QtGui/QtGui.qpb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QtGui.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QRgba64::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QRgba64",
        "rgba64",
        "QtProtobuf::uint64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rgba64'
        QtMocHelpers::PropertyData<QtProtobuf::uint64>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QRgba64, qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate5QtGui7QRgba64E[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QRgba64::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate5QtGui7QRgba64E,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui7QRgba64E_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QRgba64::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QRgba64 *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::uint64*>(_v) = _t->rgba64(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRgba64(*reinterpret_cast<QtProtobuf::uint64*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QColor::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QColor",
        "rgba64_p",
        "QtProtobufPrivate::QtGui::QRgba64*",
        "hasRgba64",
        "rgba",
        "QtProtobuf::uint32",
        "hasRgba"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rgba64_p'
        QtMocHelpers::PropertyData<QtProtobufPrivate::QtGui::QRgba64*>(1, 0x80000000 | 2, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'hasRgba64'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'rgba'
        QtMocHelpers::PropertyData<QtProtobuf::uint32>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'hasRgba'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QColor, qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate5QtGui6QColorE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QColor::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate5QtGui6QColorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QColorE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QColor *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobufPrivate::QtGui::QRgba64**>(_v) = _t->rgba64_p(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasRgba64(); break;
        case 2: *reinterpret_cast<QtProtobuf::uint32*>(_v) = _t->rgba_p(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasRgba(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRgba64_p(*reinterpret_cast<QtProtobufPrivate::QtGui::QRgba64**>(_v)); break;
        case 2: _t->setRgba_p(*reinterpret_cast<QtProtobuf::uint32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QMatrix4x4::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QMatrix4x4",
        "m",
        "QtProtobuf::floatList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'm'
        QtMocHelpers::PropertyData<QtProtobuf::floatList>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QMatrix4x4, qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QMatrix4x4::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QMatrix4x4E_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QMatrix4x4::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QMatrix4x4 *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::floatList*>(_v) = _t->m(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setM(*reinterpret_cast<QtProtobuf::floatList*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector2D::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector2D",
        "xPos",
        "yPos"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'xPos'
        QtMocHelpers::PropertyData<float>(1, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'yPos'
        QtMocHelpers::PropertyData<float>(2, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVector2D, qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector2D::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector2DE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QVector2D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QVector2D *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->xPos(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->yPos(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setXPos(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setYPos(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector3D::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector3D",
        "xPos",
        "yPos",
        "zPos"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'xPos'
        QtMocHelpers::PropertyData<float>(1, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'yPos'
        QtMocHelpers::PropertyData<float>(2, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'zPos'
        QtMocHelpers::PropertyData<float>(3, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVector3D, qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector3D::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector3DE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QVector3D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QVector3D *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->xPos(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->yPos(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->zPos(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setXPos(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setYPos(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setZPos(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector4D::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector4D",
        "xPos",
        "yPos",
        "zPos",
        "wPos"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'xPos'
        QtMocHelpers::PropertyData<float>(1, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'yPos'
        QtMocHelpers::PropertyData<float>(2, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'zPos'
        QtMocHelpers::PropertyData<float>(3, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'wPos'
        QtMocHelpers::PropertyData<float>(4, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVector4D, qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector4D::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui9QVector4DE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QVector4D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QVector4D *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->xPos(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->yPos(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->zPos(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->wPos(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setXPos(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setYPos(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setZPos(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setWPos(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QTransform::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QTransform",
        "m",
        "QtProtobuf::doubleList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'm'
        QtMocHelpers::PropertyData<QtProtobuf::doubleList>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTransform, qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QtProtobufPrivate5QtGui10QTransformE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QTransform::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QtProtobufPrivate5QtGui10QTransformE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui10QTransformE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QTransform::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QTransform *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::doubleList*>(_v) = _t->m(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setM(*reinterpret_cast<QtProtobuf::doubleList*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QQuaternion::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QQuaternion",
        "scalar",
        "x",
        "y",
        "z"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scalar'
        QtMocHelpers::PropertyData<float>(1, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'x'
        QtMocHelpers::PropertyData<float>(2, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'y'
        QtMocHelpers::PropertyData<float>(3, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'z'
        QtMocHelpers::PropertyData<float>(4, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuaternion, qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QQuaternion::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui11QQuaternionE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QQuaternion::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QQuaternion *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->scalar(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->x(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->y(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->z(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScalar(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setX(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setY(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setZ(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QImage::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QImage",
        "data",
        "format"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QByteArray>(1, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'format'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QImage, qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QImage::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QtProtobufPrivate5QtGui6QImageE_t>.metaTypes,
    nullptr
} };

void QtProtobufPrivate::QtGui::QImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QImage *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->format(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setData(*reinterpret_cast<QByteArray*>(_v)); break;
        case 1: _t->setFormat(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QRgba64_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QRgba64_QtProtobufNested",
        "QtProtobufFieldEnum",
        "Rgba64ProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::Rgba64ProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QRgba64_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QRgba64_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui24QRgba64_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QColor_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QColor_QtProtobufNested",
        "QtProtobufFieldEnum",
        "Rgba64ProtoFieldNumber",
        "RgbaProtoFieldNumber",
        "ColorFields",
        "UninitializedField",
        "Rgba64",
        "Rgba"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::Rgba64ProtoFieldNumber },
            {    3, QtProtobufFieldEnum::RgbaProtoFieldNumber },
        }),
        // enum 'ColorFields'
        QtMocHelpers::EnumData<ColorFields>(4, 4, QMC::EnumIsScoped).add({
            {    5, ColorFields::UninitializedField },
            {    6, ColorFields::Rgba64 },
            {    7, ColorFields::Rgba },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QColor_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QColor_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui23QColor_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QMatrix4x4_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QMatrix4x4_QtProtobufNested",
        "QtProtobufFieldEnum",
        "MProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::MProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QMatrix4x4_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QMatrix4x4_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui27QMatrix4x4_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector2D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector2D_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XPosProtoFieldNumber",
        "YPosProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XPosProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YPosProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QVector2D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector2D_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector2D_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector3D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector3D_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XPosProtoFieldNumber",
        "YPosProtoFieldNumber",
        "ZPosProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XPosProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YPosProtoFieldNumber },
            {    4, QtProtobufFieldEnum::ZPosProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QVector3D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector3D_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector3D_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QVector4D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QVector4D_QtProtobufNested",
        "QtProtobufFieldEnum",
        "XPosProtoFieldNumber",
        "YPosProtoFieldNumber",
        "ZPosProtoFieldNumber",
        "WPosProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::XPosProtoFieldNumber },
            {    3, QtProtobufFieldEnum::YPosProtoFieldNumber },
            {    4, QtProtobufFieldEnum::ZPosProtoFieldNumber },
            {    5, QtProtobufFieldEnum::WPosProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QVector4D_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QVector4D_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui26QVector4D_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QTransform_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QTransform_QtProtobufNested",
        "QtProtobufFieldEnum",
        "MProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::MProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QTransform_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QTransform_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui27QTransform_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QQuaternion_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QQuaternion_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ScalarProtoFieldNumber",
        "XProtoFieldNumber",
        "YProtoFieldNumber",
        "ZProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ScalarProtoFieldNumber },
            {    3, QtProtobufFieldEnum::XProtoFieldNumber },
            {    4, QtProtobufFieldEnum::YProtoFieldNumber },
            {    5, QtProtobufFieldEnum::ZProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QQuaternion_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QQuaternion_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui28QQuaternion_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobufPrivate::QtGui::QImage_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobufPrivate::QtGui::QImage_QtProtobufNested",
        "QtProtobufFieldEnum",
        "DataProtoFieldNumber",
        "FormatProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::DataProtoFieldNumber },
            {    3, QtProtobufFieldEnum::FormatProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE =
    QtProtobufPrivate::QtGui::QImage_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobufPrivate::QtGui::QImage_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17QtProtobufPrivate5QtGui23QImage_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
