/****************************************************************************
** Meta object code from reading C++ file 'qqmlgrpchttp2channel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtgrpc/src/grpcquick/qqmlgrpchttp2channel_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qqmlgrpchttp2channel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlGrpcHttp2Channel::qt_create_metaobjectdata<qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlGrpcHttp2Channel",
        "QML.Element",
        "GrpcHttp2Channel",
        "QML.AddedInVersion",
        "1543",
        "optionsChanged",
        "",
        "channelUpdated",
        "hostUriChanged",
        "hostUri",
        "QUrl",
        "options",
        "QQmlGrpcChannelOptions*",
        "channel",
        "std::shared_ptr<QAbstractGrpcChannel>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'optionsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'channelUpdated'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hostUriChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hostUri'
        QtMocHelpers::PropertyData<QUrl>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Required, 2),
        // property 'options'
        QtMocHelpers::PropertyData<QQmlGrpcChannelOptions*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'channel'
        QtMocHelpers::PropertyData<std::shared_ptr<QAbstractGrpcChannel>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlGrpcHttp2Channel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlGrpcHttp2Channel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlAbstractGrpcChannel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t>.metaTypes,
    nullptr
} };

void QQmlGrpcHttp2Channel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQmlGrpcHttp2Channel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->optionsChanged(); break;
        case 1: _t->channelUpdated(); break;
        case 2: _t->hostUriChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcHttp2Channel::*)()>(_a, &QQmlGrpcHttp2Channel::optionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcHttp2Channel::*)()>(_a, &QQmlGrpcHttp2Channel::channelUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcHttp2Channel::*)()>(_a, &QQmlGrpcHttp2Channel::hostUriChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlGrpcChannelOptions* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->hostUri(); break;
        case 1: *reinterpret_cast<QQmlGrpcChannelOptions**>(_v) = _t->options(); break;
        case 2: *reinterpret_cast<std::shared_ptr<QAbstractGrpcChannel>*>(_v) = _t->channel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHostUri(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setOptions(*reinterpret_cast<QQmlGrpcChannelOptions**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQmlGrpcHttp2Channel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQmlGrpcHttp2Channel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQmlGrpcHttp2ChannelE_t>.strings))
        return static_cast<void*>(this);
    return QQmlAbstractGrpcChannel::qt_metacast(_clname);
}

int QQmlGrpcHttp2Channel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlAbstractGrpcChannel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQmlGrpcHttp2Channel::optionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQmlGrpcHttp2Channel::channelUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQmlGrpcHttp2Channel::hostUriChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
