/****************************************************************************
** Meta object code from reading C++ file 'qqmlgrpcchanneloptions_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtgrpc/src/grpcquick/qqmlgrpcchanneloptions_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qqmlgrpcchanneloptions_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlGrpcChannelOptions::qt_create_metaobjectdata<qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlGrpcChannelOptions",
        "QML.Element",
        "GrpcChannelOptions",
        "QML.AddedInVersion",
        "1543",
        "deadlineTimeoutChanged",
        "",
        "metadataChanged",
        "serializationFormatChanged",
        "sslConfigurationChanged",
        "deadlineTimeout",
        "metadata",
        "QQmlGrpcMetadata*",
        "serializationFormat",
        "QtGrpc::SerializationFormat",
        "sslConfiguration",
        "QQmlSslConfiguration"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deadlineTimeoutChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serializationFormatChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sslConfigurationChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'deadlineTimeout'
        QtMocHelpers::PropertyData<qint64>(10, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'metadata'
        QtMocHelpers::PropertyData<QQmlGrpcMetadata*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'serializationFormat'
        QtMocHelpers::PropertyData<QtGrpc::SerializationFormat>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'sslConfiguration'
        QtMocHelpers::PropertyData<QQmlSslConfiguration>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlGrpcChannelOptions, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN22QQmlGrpcChannelOptionsE[] = {
    QMetaObject::SuperData::link<QtGrpc::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQmlGrpcChannelOptions::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN22QQmlGrpcChannelOptionsE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t>.metaTypes,
    nullptr
} };

void QQmlGrpcChannelOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQmlGrpcChannelOptions *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deadlineTimeoutChanged(); break;
        case 1: _t->metadataChanged(); break;
        case 2: _t->serializationFormatChanged(); break;
        case 3: _t->sslConfigurationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcChannelOptions::*)()>(_a, &QQmlGrpcChannelOptions::deadlineTimeoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcChannelOptions::*)()>(_a, &QQmlGrpcChannelOptions::metadataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcChannelOptions::*)()>(_a, &QQmlGrpcChannelOptions::serializationFormatChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQmlGrpcChannelOptions::*)()>(_a, &QQmlGrpcChannelOptions::sslConfigurationChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint64*>(_v) = _t->deadlineTimeout(); break;
        case 1: *reinterpret_cast<QQmlGrpcMetadata**>(_v) = _t->metadata(); break;
        case 2: *reinterpret_cast<QtGrpc::SerializationFormat*>(_v) = _t->serializationFormat(); break;
        case 3: *reinterpret_cast<QQmlSslConfiguration*>(_v) = _t->sslConfiguration(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDeadlineTimeout(*reinterpret_cast<qint64*>(_v)); break;
        case 1: _t->setMetadata(*reinterpret_cast<QQmlGrpcMetadata**>(_v)); break;
        case 2: _t->setSerializationFormat(*reinterpret_cast<QtGrpc::SerializationFormat*>(_v)); break;
        case 3: _t->setSslConfiguration(*reinterpret_cast<QQmlSslConfiguration*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQmlGrpcChannelOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQmlGrpcChannelOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQmlGrpcChannelOptionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQmlGrpcChannelOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQmlGrpcChannelOptions::deadlineTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQmlGrpcChannelOptions::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQmlGrpcChannelOptions::serializationFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQmlGrpcChannelOptions::sslConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
