/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qqmlprotobuftypes_p.h>)
#  include <private/qqmlprotobuftypes_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtProtobuf()
{
    qmlRegisterModule("QtProtobuf", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QQmlProtobufBoolListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufBoolListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufDoubleListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufDoubleListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufFixed32ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufFixed32ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufFixed64ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufFixed64ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufFloatListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufFloatListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufInt32ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufInt32ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufInt64ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufInt64ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufSFixed32ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufSFixed32ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufSFixed64ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufSFixed64ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufSInt32ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufSInt32ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufSInt64ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufSInt64ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufUInt32ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufUInt32ListForeign *>().id();
    qmlRegisterTypesAndRevisions<QQmlProtobufUInt64ListForeign>("QtProtobuf", 6);
    QMetaType::fromType<QQmlProtobufUInt64ListForeign *>().id();
    QT_WARNING_POP
    qmlRegisterModule("QtProtobuf", 6, 12);
}

static const QQmlModuleRegistration qtProtobufRegistration("QtProtobuf", qml_register_types_QtProtobuf);
