/****************************************************************************
** Meta object code from reading C++ file 'qtprotobuftypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtgrpc/src/protobuf/qtprotobuftypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtprotobuftypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QtProtobufE_t {};
} // unnamed namespace

template <> constexpr inline auto QtProtobuf::qt_create_metaobjectdata<qt_meta_tag_ZN10QtProtobufE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtProtobuf",
        "WireTypes",
        "Unknown",
        "Varint",
        "Fixed64",
        "LengthDelimited",
        "StartGroup",
        "EndGroup",
        "Fixed32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'WireTypes'
        QtMocHelpers::EnumData<WireTypes>(1, 1, QMC::EnumIsScoped).add({
            {    2, WireTypes::Unknown },
            {    3, WireTypes::Varint },
            {    4, WireTypes::Fixed64 },
            {    5, WireTypes::LengthDelimited },
            {    6, WireTypes::StartGroup },
            {    7, WireTypes::EndGroup },
            {    8, WireTypes::Fixed32 },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10QtProtobufE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN10QtProtobufE =
    QtProtobuf::qt_create_metaobjectdata<qt_meta_tag_ZN10QtProtobufE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10QtProtobufE =
    qt_staticMetaObjectContent_ZN10QtProtobufE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10QtProtobufE =
    qt_staticMetaObjectContent_ZN10QtProtobufE.relocatingData;

Q_CONSTINIT const QMetaObject QtProtobuf::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10QtProtobufE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10QtProtobufE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10QtProtobufE.metaTypes,
    nullptr
} };

QT_WARNING_POP
