/****************************************************************************
** Meta object code from reading C++ file 'qqmlprotobuftypes_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtgrpc/src/protobufquick/qqmlprotobuftypes_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qqmlprotobuftypes_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QQmlProtobufInt32ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufInt32Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN24QQmlProtobufInt32ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufInt32Foreign",
        "QML.Foreign",
        "QtProtobuf::int32",
        "QML.Using",
        "int32_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufInt32Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufInt32Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQmlProtobufInt32ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQmlProtobufInt32ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQmlProtobufInt32ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24QQmlProtobufInt64ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufInt64Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN24QQmlProtobufInt64ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufInt64Foreign",
        "QML.Foreign",
        "QtProtobuf::int64",
        "QML.Using",
        "int64_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufInt64Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufInt64Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQmlProtobufInt64ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQmlProtobufInt64ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQmlProtobufInt64ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26QQmlProtobufFixed32ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufFixed32Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN26QQmlProtobufFixed32ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufFixed32Foreign",
        "QML.Foreign",
        "QtProtobuf::fixed32",
        "QML.Using",
        "uint32_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufFixed32Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufFixed32Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQmlProtobufFixed32ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQmlProtobufFixed32ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QQmlProtobufFixed32ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26QQmlProtobufFixed64ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufFixed64Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN26QQmlProtobufFixed64ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufFixed64Foreign",
        "QML.Foreign",
        "QtProtobuf::fixed64",
        "QML.Using",
        "uint64_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufFixed64Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufFixed64Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQmlProtobufFixed64ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQmlProtobufFixed64ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QQmlProtobufFixed64ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN27QQmlProtobufSFixed32ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSFixed32Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN27QQmlProtobufSFixed32ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSFixed32Foreign",
        "QML.Foreign",
        "QtProtobuf::sfixed32",
        "QML.Using",
        "int32_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSFixed32Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSFixed32Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufSFixed32ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufSFixed32ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27QQmlProtobufSFixed32ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN27QQmlProtobufSFixed64ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSFixed64Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN27QQmlProtobufSFixed64ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSFixed64Foreign",
        "QML.Foreign",
        "QtProtobuf::sfixed64",
        "QML.Using",
        "int64_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSFixed64Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSFixed64Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufSFixed64ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufSFixed64ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27QQmlProtobufSFixed64ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN25QQmlProtobufUInt32ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufUInt32Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN25QQmlProtobufUInt32ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufUInt32Foreign",
        "QML.Foreign",
        "QtProtobuf::uint32",
        "QML.Using",
        "uint32_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufUInt32Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufUInt32Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufUInt32ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufUInt32ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQmlProtobufUInt32ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN25QQmlProtobufUInt64ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufUInt64Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN25QQmlProtobufUInt64ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufUInt64Foreign",
        "QML.Foreign",
        "QtProtobuf::uint64",
        "QML.Using",
        "uint64_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufUInt64Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufUInt64Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufUInt64ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufUInt64ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQmlProtobufUInt64ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN25QQmlProtobufSInt32ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSInt32Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN25QQmlProtobufSInt32ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSInt32Foreign",
        "QML.Foreign",
        "QtProtobuf::sint32",
        "QML.Using",
        "int32_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSInt32Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSInt32Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufSInt32ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufSInt32ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQmlProtobufSInt32ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN25QQmlProtobufSInt64ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSInt64Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN25QQmlProtobufSInt64ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSInt64Foreign",
        "QML.Foreign",
        "QtProtobuf::sint64",
        "QML.Using",
        "int64_t"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSInt64Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSInt64Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufSInt64ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQmlProtobufSInt64ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQmlProtobufSInt64ForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN27QQmlProtobufBoolListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufBoolListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN27QQmlProtobufBoolListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufBoolListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::boolList",
        "QML.Sequence",
        "bool"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufBoolListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufBoolListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufBoolListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQmlProtobufBoolListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27QQmlProtobufBoolListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN28QQmlProtobufFloatListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufFloatListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28QQmlProtobufFloatListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufFloatListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::floatList",
        "QML.Sequence",
        "float"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufFloatListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufFloatListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufFloatListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufFloatListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQmlProtobufFloatListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29QQmlProtobufDoubleListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufDoubleListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29QQmlProtobufDoubleListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufDoubleListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::doubleList",
        "QML.Sequence",
        "double"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufDoubleListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufDoubleListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufDoubleListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufDoubleListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQmlProtobufDoubleListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN28QQmlProtobufInt32ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufInt32ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28QQmlProtobufInt32ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufInt32ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::int32List",
        "QML.Sequence",
        "QtProtobuf::int32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufInt32ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufInt32ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufInt32ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufInt32ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQmlProtobufInt32ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN28QQmlProtobufInt64ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufInt64ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28QQmlProtobufInt64ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufInt64ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::int64List",
        "QML.Sequence",
        "QtProtobuf::int64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufInt64ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufInt64ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufInt64ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQmlProtobufInt64ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQmlProtobufInt64ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29QQmlProtobufUInt32ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufUInt32ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29QQmlProtobufUInt32ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufUInt32ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::uint32List",
        "QML.Sequence",
        "QtProtobuf::uint32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufUInt32ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufUInt32ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufUInt32ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufUInt32ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQmlProtobufUInt32ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29QQmlProtobufUInt64ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufUInt64ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29QQmlProtobufUInt64ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufUInt64ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::uint64List",
        "QML.Sequence",
        "QtProtobuf::uint64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufUInt64ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufUInt64ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufUInt64ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufUInt64ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQmlProtobufUInt64ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29QQmlProtobufSInt32ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSInt32ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29QQmlProtobufSInt32ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSInt32ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::sint32List",
        "QML.Sequence",
        "QtProtobuf::sint32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSInt32ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSInt32ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufSInt32ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufSInt32ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQmlProtobufSInt32ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29QQmlProtobufSInt64ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSInt64ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29QQmlProtobufSInt64ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSInt64ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::sint64List",
        "QML.Sequence",
        "QtProtobuf::sint64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSInt64ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSInt64ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufSInt64ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQmlProtobufSInt64ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQmlProtobufSInt64ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN30QQmlProtobufFixed32ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufFixed32ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN30QQmlProtobufFixed32ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufFixed32ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::fixed32List",
        "QML.Sequence",
        "QtProtobuf::fixed32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufFixed32ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufFixed32ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQmlProtobufFixed32ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQmlProtobufFixed32ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQmlProtobufFixed32ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN30QQmlProtobufFixed64ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufFixed64ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN30QQmlProtobufFixed64ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufFixed64ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::fixed64List",
        "QML.Sequence",
        "QtProtobuf::fixed64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufFixed64ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufFixed64ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQmlProtobufFixed64ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQmlProtobufFixed64ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQmlProtobufFixed64ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN31QQmlProtobufSFixed32ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSFixed32ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN31QQmlProtobufSFixed32ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSFixed32ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::sfixed32List",
        "QML.Sequence",
        "QtProtobuf::sfixed32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSFixed32ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSFixed32ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQmlProtobufSFixed32ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQmlProtobufSFixed32ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QQmlProtobufSFixed32ListForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN31QQmlProtobufSFixed64ListForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQmlProtobufSFixed64ListForeign::qt_create_metaobjectdata<qt_meta_tag_ZN31QQmlProtobufSFixed64ListForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQmlProtobufSFixed64ListForeign",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QtProtobuf::sfixed64List",
        "QML.Sequence",
        "QtProtobuf::sfixed64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQmlProtobufSFixed64ListForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQmlProtobufSFixed64ListForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQmlProtobufSFixed64ListForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQmlProtobufSFixed64ListForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QQmlProtobufSFixed64ListForeignE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
