/****************************************************************************
** Meta object code from reading C++ file 'wrappers.qpb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../google/protobuf/wrappers.qpb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wrappers.qpb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6google8protobuf11DoubleValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::DoubleValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf11DoubleValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::DoubleValue",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<double>(1, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DoubleValue, qt_meta_tag_ZN6google8protobuf11DoubleValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::DoubleValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11DoubleValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11DoubleValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf11DoubleValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::DoubleValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<DoubleValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf10FloatValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::FloatValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf10FloatValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::FloatValue",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<float>(1, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FloatValue, qt_meta_tag_ZN6google8protobuf10FloatValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::FloatValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10FloatValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10FloatValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf10FloatValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::FloatValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<FloatValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf10Int64ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Int64Value::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf10Int64ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Int64Value",
        "value",
        "QtProtobuf::int64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QtProtobuf::int64>(1, 0x80000000 | 2, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Stored | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Int64Value, qt_meta_tag_ZN6google8protobuf10Int64ValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf10Int64ValueE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Int64Value::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10Int64ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10Int64ValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf10Int64ValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf10Int64ValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Int64Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Int64Value *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int64 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int64*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QtProtobuf::int64*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::UInt64Value::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::UInt64Value",
        "value",
        "QtProtobuf::uint64"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QtProtobuf::uint64>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UInt64Value, qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf11UInt64ValueE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::UInt64Value::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf11UInt64ValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf11UInt64ValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::UInt64Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<UInt64Value *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::uint64*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QtProtobuf::uint64*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf10Int32ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Int32Value::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf10Int32ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Int32Value",
        "value",
        "QtProtobuf::int32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QtProtobuf::int32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Int32Value, qt_meta_tag_ZN6google8protobuf10Int32ValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf10Int32ValueE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::Int32Value::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10Int32ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10Int32ValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf10Int32ValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf10Int32ValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::Int32Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Int32Value *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtProtobuf::int32 >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::int32*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QtProtobuf::int32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::UInt32Value::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::UInt32Value",
        "value",
        "QtProtobuf::uint32"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QtProtobuf::uint32>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UInt32Value, qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6google8protobuf11UInt32ValueE[] = {
    QMetaObject::SuperData::link<QtProtobuf::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject google::protobuf::UInt32Value::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6google8protobuf11UInt32ValueE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf11UInt32ValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::UInt32Value::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<UInt32Value *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QtProtobuf::uint32*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QtProtobuf::uint32*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf9BoolValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::BoolValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf9BoolValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::BoolValue",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BoolValue, qt_meta_tag_ZN6google8protobuf9BoolValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::BoolValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9BoolValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf9BoolValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf9BoolValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::BoolValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<BoolValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf11StringValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::StringValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf11StringValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::StringValue",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StringValue, qt_meta_tag_ZN6google8protobuf11StringValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::StringValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11StringValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf11StringValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf11StringValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::StringValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<StringValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf10BytesValueE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::BytesValue::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf10BytesValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::BytesValue",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QByteArray>(1, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BytesValue, qt_meta_tag_ZN6google8protobuf10BytesValueE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject google::protobuf::BytesValue::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QProtobufMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10BytesValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6google8protobuf10BytesValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6google8protobuf10BytesValueE_t>.metaTypes,
    nullptr
} };

void google::protobuf::BytesValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<BytesValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN6google8protobuf28DoubleValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::DoubleValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28DoubleValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::DoubleValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf28DoubleValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE =
    google::protobuf::DoubleValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28DoubleValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::DoubleValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28DoubleValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf27FloatValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::FloatValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27FloatValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::FloatValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf27FloatValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE =
    google::protobuf::FloatValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27FloatValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::FloatValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27FloatValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf27Int64Value_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Int64Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27Int64Value_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Int64Value_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf27Int64Value_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE =
    google::protobuf::Int64Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27Int64Value_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Int64Value_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27Int64Value_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf28UInt64Value_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::UInt64Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28UInt64Value_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::UInt64Value_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf28UInt64Value_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE =
    google::protobuf::UInt64Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28UInt64Value_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::UInt64Value_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28UInt64Value_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf27Int32Value_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::Int32Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27Int32Value_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::Int32Value_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf27Int32Value_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE =
    google::protobuf::Int32Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27Int32Value_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::Int32Value_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27Int32Value_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf28UInt32Value_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::UInt32Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28UInt32Value_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::UInt32Value_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf28UInt32Value_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE =
    google::protobuf::UInt32Value_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28UInt32Value_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::UInt32Value_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28UInt32Value_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf26BoolValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::BoolValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26BoolValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::BoolValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf26BoolValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE =
    google::protobuf::BoolValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf26BoolValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::BoolValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf26BoolValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf28StringValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::StringValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28StringValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::StringValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf28StringValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf28StringValue_QtProtobufNestedE =
    google::protobuf::StringValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf28StringValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf28StringValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28StringValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28StringValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf28StringValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::StringValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28StringValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf28StringValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf28StringValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN6google8protobuf27BytesValue_QtProtobufNestedE_t {};
} // unnamed namespace

template <> constexpr inline auto google::protobuf::BytesValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27BytesValue_QtProtobufNestedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "google::protobuf::BytesValue_QtProtobufNested",
        "QtProtobufFieldEnum",
        "ValueProtoFieldNumber"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QtProtobufFieldEnum'
        QtMocHelpers::EnumData<QtProtobufFieldEnum>(1, 1, QMC::EnumIsScoped).add({
            {    2, QtProtobufFieldEnum::ValueProtoFieldNumber },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6google8protobuf27BytesValue_QtProtobufNestedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE =
    google::protobuf::BytesValue_QtProtobufNested::qt_create_metaobjectdata<qt_meta_tag_ZN6google8protobuf27BytesValue_QtProtobufNestedE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE =
    qt_staticMetaObjectContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE.relocatingData;

Q_CONSTINIT const QMetaObject google::protobuf::BytesValue_QtProtobufNested::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6google8protobuf27BytesValue_QtProtobufNestedE.metaTypes,
    nullptr
} };

QT_WARNING_POP
