
#include "google/protobuf/api.qpb.h"

#include <QtProtobuf/qprotobufregistration.h>

namespace google::protobuf {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarApi(qRegisterProtobufType<Api>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarMethod(qRegisterProtobufType<Method>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarMixin(qRegisterProtobufType<Mixin>);
static bool RegisterApiProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace google::protobuf

